# Defense elements

## Detectors

::: agentdojo.agent_pipeline.PromptInjectionDetector
    options:
        filters: ["!query"]
        heading_level: 3

::: agentdojo.agent_pipeline.TransformersBasedPIDetector
    options:
        filters: ["!query"]
        heading_level: 3
